#!/usr/bin/env node
"use strict";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

var path = require('path');

var fs = require('fs');

var program = require('commander');

var version = require('../package.json').version;

var readObj = function readObj(obj, prop) {
  var propArr = prop.split('.');
  var result = obj;
  propArr.forEach(function (p) {
    result = result[p];
  });
  return result;
};

var readJson = function readJson(subpath, props) {
  return new Promise(function (resolve, reject) {
    var filepath = path.resolve(process.cwd(), subpath);
    var isExists = fs.existsSync(filepath);

    if (isExists) {
      var fileContent = fs.readFileSync(filepath).toString('utf-8');
      var fileObj = {};

      try {
        fileObj = JSON.parse(fileContent);
        resolve(fileObj);
      } catch (e) {
        reject("file: ".concat(subpath, " can not be parsed as JSON:\n ").concat(e));
      }
    } else {
      reject('file: ${subpath} can not be found');
    }
  });
};

var printJson = function printJson(obj, props) {
  if (Array.isArray(props) && props.length > 0) {
    props.forEach(function (prop) {
      console.log(JSON.stringify(readObj(obj, prop), null, 4));
    });
  } else {
    console.log(JSON.stringify(obj, null, 4));
  }
};

var printJsonAfterRead = function printJsonAfterRead(subpath, props) {
  return readJson(subpath).then(function (obj) {
    printJson(obj, props);
  });
};

var printKeysAfterRead = function printKeysAfterRead(subpath, prop) {
  return readJson(subpath).then(function (obj) {
    var target = prop !== undefined ? readObj(obj, prop) : obj;
    target && _typeof(target) === 'object' ? console.log(Object.keys(target)) : console.log('no prop exists in target');
  });
};

program.version(version);
program.arguments('<file> [props...]').action(printJsonAfterRead);
program.command('read <file> [props...]').action(printJsonAfterRead);
program.command('keys <file> [prop]').action(printKeysAfterRead);
program.parse(process.argv);
